@@ -4,7 +4,7 @@ use Mojolicious::Plugin::AssetPack::Asset::Null;
 use Mojolicious::Plugin::AssetPack::Store;
 use Mojolicious::Plugin::AssetPack::Util qw(diag has_ro load_module DEBUG);
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 has minify => sub { shift->_app->mode eq 'development' ? 0 : 1 };
 
@@ -41,11 +41,12 @@ sub process {
   # TODO: The idea with blessed($_) is that maybe the user can pass inn
   # Mojolicious::Plugin::AssetPack::Sprites object, with images to generate
   # CSS from?
-  for my $f (@input) {
-    $f = $self->store->asset($f) unless Scalar::Util::blessed($f);
-    $f->_reset->content($self->store->asset($f->url)) if $self->{input}{$topic};
-    $f->$_ for qw(checksum mtime);
-    push @$assets, $f;
+  for my $i (@input) {
+    my $asset = Scalar::Util::blessed($i) ? $i : $self->store->asset($i);
+    die "Could not find asset '$i'." unless Scalar::Util::blessed($asset);
+    $asset->_reset->content($self->store->asset($asset->url)) if $self->{input}{$topic};
+    $asset->$_ for qw(checksum mtime);
+    push @$assets, $asset;
   }
 
   # hack to enable Reloader to work
@@ -198,7 +199,7 @@ sub _tag_helpers {
   return $assets->grep(sub { !$_->isa('Mojolicious::Plugin::AssetPack::Asset::Null') })
     ->map(
     sub {
-      my $tag_helper = $_->format eq 'js' ? 'javascript' : 'stylesheet';
+      my $tag_helper = $_->tag_helper;
       my $url = Mojo::URL->new($base_url . $c->url_for(assetpack => $_->TO_JSON));
       $c->$tag_helper($url, @attrs);
     }
@@ -220,7 +221,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-1.07
+1.08
 
 =head1 SYNOPSIS
 
